"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import Any, TYPE_CHECKING

from factify.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .acceptorganizationinviteop import (
        AcceptOrganizationInviteAcceptOrganizationInviteRequest,
        AcceptOrganizationInviteAcceptOrganizationInviteRequestTypedDict,
        AcceptOrganizationInviteRequest,
        AcceptOrganizationInviteRequestTypedDict,
        AcceptOrganizationInviteResponseResponse,
        AcceptOrganizationInviteResponseResponseTypedDict,
    )
    from .acceptorganizationinviteresponse import (
        AcceptOrganizationInviteResponse,
        AcceptOrganizationInviteResponseTypedDict,
    )
    from .accessgrantresult import AccessGrantResult, AccessGrantResultTypedDict
    from .accesslevel import AccessLevel
    from .accessrequest import AccessRequest, AccessRequestTypedDict
    from .accessrequestpermission import AccessRequestPermission
    from .accessrequeststatus import AccessRequestStatus
    from .addorganizationmemberop import (
        AddOrganizationMemberAddOrganizationMemberRequest,
        AddOrganizationMemberAddOrganizationMemberRequestTypedDict,
        AddOrganizationMemberRequest,
        AddOrganizationMemberRequestTypedDict,
        AddOrganizationMemberResponseResponse,
        AddOrganizationMemberResponseResponseTypedDict,
    )
    from .addorganizationmemberresponse import (
        AddOrganizationMemberResponse,
        AddOrganizationMemberResponseTypedDict,
    )
    from .apikey import APIKey, APIKeyTypedDict
    from .apikeyquota import APIKeyQuota, APIKeyQuotaTypedDict
    from .approveaccessrequestop import (
        ApproveAccessRequestApproveAccessRequestRequest,
        ApproveAccessRequestApproveAccessRequestRequestTypedDict,
        ApproveAccessRequestRequest,
        ApproveAccessRequestRequestTypedDict,
        ApproveAccessRequestResponseResponse,
        ApproveAccessRequestResponseResponseTypedDict,
    )
    from .approveaccessrequestresponse import (
        ApproveAccessRequestResponse,
        ApproveAccessRequestResponseTypedDict,
    )
    from .attachdocumentpolicyop import (
        AttachDocumentPolicyRequest,
        AttachDocumentPolicyRequestTypedDict,
        AttachDocumentPolicyResponse,
        AttachDocumentPolicyResponseTypedDict,
        AttachPolicyRequest,
        AttachPolicyRequestTypedDict,
    )
    from .checkaccessrequeststatusop import (
        CheckAccessRequestStatusRequest,
        CheckAccessRequestStatusRequestTypedDict,
        CheckAccessRequestStatusResponseResponse,
        CheckAccessRequestStatusResponseResponseTypedDict,
    )
    from .checkaccessrequeststatusresponse import (
        CheckAccessRequestStatusResponse,
        CheckAccessRequestStatusResponseTypedDict,
    )
    from .createaccessrequestop import (
        CreateAccessRequestCreateAccessRequestRequest,
        CreateAccessRequestCreateAccessRequestRequestTypedDict,
        CreateAccessRequestRequest,
        CreateAccessRequestRequestTypedDict,
        CreateAccessRequestResponseResponse,
        CreateAccessRequestResponseResponseTypedDict,
    )
    from .createaccessrequestresponse import (
        CreateAccessRequestResponse,
        CreateAccessRequestResponseTypedDict,
    )
    from .createapikeyop import (
        CreateAPIKeyResponseResponse,
        CreateAPIKeyResponseResponseTypedDict,
    )
    from .createapikeyrequest import CreateAPIKeyRequest, CreateAPIKeyRequestTypedDict
    from .createapikeyresponse import (
        CreateAPIKeyResponse,
        CreateAPIKeyResponseTypedDict,
    )
    from .createdocumentop import (
        CreateDocumentResponseResponse,
        CreateDocumentResponseResponseTypedDict,
    )
    from .createdocumentrequest import (
        CreateDocumentRequest,
        CreateDocumentRequestPayload,
        CreateDocumentRequestPayloadTypedDict,
        CreateDocumentRequestTypedDict,
    )
    from .createdocumentresponse import (
        CreateDocumentResponse,
        CreateDocumentResponseTypedDict,
    )
    from .createdocumentversionop import (
        CreateDocumentVersionRequest,
        CreateDocumentVersionRequestTypedDict,
        CreateDocumentVersionResponse,
        CreateDocumentVersionResponseTypedDict,
    )
    from .createorganizationinviteop import (
        CreateOrganizationInviteCreateOrganizationInviteRequest,
        CreateOrganizationInviteCreateOrganizationInviteRequestTypedDict,
        CreateOrganizationInviteRequest,
        CreateOrganizationInviteRequestTypedDict,
        CreateOrganizationInviteResponseResponse,
        CreateOrganizationInviteResponseResponseTypedDict,
    )
    from .createorganizationinviteresponse import (
        CreateOrganizationInviteResponse,
        CreateOrganizationInviteResponseTypedDict,
    )
    from .createsharelinkop import (
        CreateShareLinkCreateShareLinkRequest,
        CreateShareLinkCreateShareLinkRequestTypedDict,
        CreateShareLinkRequest,
        CreateShareLinkRequestTypedDict,
        CreateShareLinkResponseResponse,
        CreateShareLinkResponseResponseTypedDict,
    )
    from .createsharelinkresponse import (
        CreateShareLinkResponse,
        CreateShareLinkResponseTypedDict,
    )
    from .createversionrequest import (
        CreateVersionRequest,
        CreateVersionRequestPayload,
        CreateVersionRequestPayloadTypedDict,
        CreateVersionRequestTypedDict,
    )
    from .dailyusage import DailyUsage, DailyUsageTypedDict
    from .deleteapikeyquotaop import (
        DeleteAPIKeyQuotaRequest,
        DeleteAPIKeyQuotaRequestTypedDict,
        DeleteAPIKeyQuotaResponseResponse,
        DeleteAPIKeyQuotaResponseResponseTypedDict,
    )
    from .deleteapikeyquotaresponse import (
        DeleteAPIKeyQuotaResponse,
        DeleteAPIKeyQuotaResponseTypedDict,
    )
    from .denyaccessrequestop import (
        DenyAccessRequestDenyAccessRequestRequest,
        DenyAccessRequestDenyAccessRequestRequestTypedDict,
        DenyAccessRequestRequest,
        DenyAccessRequestRequestTypedDict,
        DenyAccessRequestResponseResponse,
        DenyAccessRequestResponseResponseTypedDict,
    )
    from .denyaccessrequestresponse import (
        DenyAccessRequestResponse,
        DenyAccessRequestResponseTypedDict,
    )
    from .detachdocumentpolicyop import (
        DetachDocumentPolicyRequest,
        DetachDocumentPolicyRequestTypedDict,
        DetachDocumentPolicyResponse,
        DetachDocumentPolicyResponseTypedDict,
    )
    from .document import Document, DocumentTypedDict
    from .documentownership import DocumentOwnership
    from .documentpermissionset import (
        DocumentPermissionSet,
        DocumentPermissionSetTypedDict,
    )
    from .documentpolicy import DocumentPolicy, DocumentPolicyTypedDict
    from .documentrole import DocumentRole
    from .documenttrashstate import DocumentTrashState
    from .duplicatedocument import DuplicateDocument, DuplicateDocumentTypedDict
    from .empty import Empty, EmptyTypedDict
    from .errordetail import ErrorDetail, ErrorDetailTypedDict, Reason
    from .errorresponse import Code
    from .exportdocumentop import (
        ExportDocumentRequest,
        ExportDocumentRequestTypedDict,
        ExportDocumentResponseResponse,
        ExportDocumentResponseResponseTypedDict,
    )
    from .exportdocumentresponse import (
        ExportDocumentResponse,
        ExportDocumentResponseTypedDict,
    )
    from .generalaccesslevel import GeneralAccessLevel
    from .generatedocumententrypageop import (
        GenerateDocumentEntryPageRequest,
        GenerateDocumentEntryPageRequestTypedDict,
        GenerateDocumentEntryPageResponse,
        GenerateDocumentEntryPageResponseTypedDict,
    )
    from .generateentrypageresponse import (
        GenerateEntryPageResponse,
        GenerateEntryPageResponseTypedDict,
    )
    from .getdocumentop import (
        GetDocumentRequest,
        GetDocumentRequestTypedDict,
        GetDocumentResponseResponse,
        GetDocumentResponseResponseTypedDict,
    )
    from .getdocumentquotaop import (
        GetDocumentQuotaResponseResponse,
        GetDocumentQuotaResponseResponseTypedDict,
    )
    from .getdocumentquotaresponse import (
        GetDocumentQuotaResponse,
        GetDocumentQuotaResponseTypedDict,
    )
    from .getdocumentresponse import GetDocumentResponse, GetDocumentResponseTypedDict
    from .getdocumenttimelineop import (
        GetDocumentTimelineRequest,
        GetDocumentTimelineRequestTypedDict,
        GetDocumentTimelineResponse,
        GetDocumentTimelineResponseTypedDict,
    )
    from .getgeneralaccessop import (
        GetGeneralAccessRequest,
        GetGeneralAccessRequestTypedDict,
        GetGeneralAccessResponseResponse,
        GetGeneralAccessResponseResponseTypedDict,
    )
    from .getgeneralaccessresponse import (
        GetGeneralAccessResponse,
        GetGeneralAccessResponseTypedDict,
    )
    from .getmeop import GetMeResponseResponse, GetMeResponseResponseTypedDict
    from .getmeresponse import GetMeResponse, GetMeResponseTypedDict
    from .getorganizationop import (
        GetOrganizationRequest,
        GetOrganizationRequestTypedDict,
        GetOrganizationResponseResponse,
        GetOrganizationResponseResponseTypedDict,
    )
    from .getorganizationquotaop import (
        GetOrganizationQuotaRequest,
        GetOrganizationQuotaRequestTypedDict,
        GetOrganizationQuotaResponseResponse,
        GetOrganizationQuotaResponseResponseTypedDict,
    )
    from .getorganizationquotaresponse import (
        GetOrganizationQuotaResponse,
        GetOrganizationQuotaResponseTypedDict,
    )
    from .getorganizationresponse import (
        GetOrganizationResponse,
        GetOrganizationResponseTypedDict,
    )
    from .gettimelineresponse import GetTimelineResponse, GetTimelineResponseTypedDict
    from .getusagehistoryop import (
        GetUsageHistoryRequest,
        GetUsageHistoryRequestTypedDict,
        GetUsageHistoryResponseResponse,
        GetUsageHistoryResponseResponseTypedDict,
    )
    from .getusagehistoryresponse import (
        GetUsageHistoryResponse,
        GetUsageHistoryResponseTypedDict,
    )
    from .getuserpreferencesop import (
        GetUserPreferencesResponseResponse,
        GetUserPreferencesResponseResponseTypedDict,
    )
    from .getuserpreferencesresponse import (
        GetUserPreferencesResponse,
        GetUserPreferencesResponseTypedDict,
    )
    from .getversionop import (
        GetVersionRequest,
        GetVersionRequestTypedDict,
        GetVersionResponse,
        GetVersionResponseTypedDict,
    )
    from .grantdocumentaccessop import (
        GrantDocumentAccessGrantDocumentAccessRequest,
        GrantDocumentAccessGrantDocumentAccessRequestTypedDict,
        GrantDocumentAccessRequest,
        GrantDocumentAccessRequestTypedDict,
        GrantDocumentAccessResponseResponse,
        GrantDocumentAccessResponseResponseTypedDict,
    )
    from .grantdocumentaccessresponse import (
        GrantDocumentAccessResponse,
        GrantDocumentAccessResponseTypedDict,
    )
    from .inspectaccessresponse import (
        InspectAccessResponse,
        InspectAccessResponseTypedDict,
    )
    from .inspectdocumentaccessop import (
        InspectDocumentAccessRequest,
        InspectDocumentAccessRequestTypedDict,
        InspectDocumentAccessResponse,
        InspectDocumentAccessResponseTypedDict,
    )
    from .listaccessrequestsop import (
        ListAccessRequestsRequest,
        ListAccessRequestsRequestTypedDict,
        ListAccessRequestsResponseResponse,
        ListAccessRequestsResponseResponseTypedDict,
    )
    from .listaccessrequestsresponse import (
        ListAccessRequestsResponse,
        ListAccessRequestsResponseTypedDict,
    )
    from .listapikeyquotasop import (
        ListAPIKeyQuotasRequest,
        ListAPIKeyQuotasRequestTypedDict,
        ListAPIKeyQuotasResponseResponse,
        ListAPIKeyQuotasResponseResponseTypedDict,
    )
    from .listapikeyquotasresponse import (
        ListAPIKeyQuotasResponse,
        ListAPIKeyQuotasResponseTypedDict,
    )
    from .listapikeysop import (
        ListAPIKeysRequest,
        ListAPIKeysRequestTypedDict,
        ListAPIKeysResponseResponse,
        ListAPIKeysResponseResponseTypedDict,
    )
    from .listapikeysresponse import ListAPIKeysResponse, ListAPIKeysResponseTypedDict
    from .listdocumentaccessop import (
        ListDocumentAccessRequest,
        ListDocumentAccessRequestTypedDict,
        ListDocumentAccessResponseResponse,
        ListDocumentAccessResponseResponseTypedDict,
    )
    from .listdocumentaccessresponse import (
        ListDocumentAccessResponse,
        ListDocumentAccessResponseTypedDict,
    )
    from .listdocumentduplicatesop import (
        ListDocumentDuplicatesRequest,
        ListDocumentDuplicatesRequestTypedDict,
        ListDocumentDuplicatesResponseResponse,
        ListDocumentDuplicatesResponseResponseTypedDict,
    )
    from .listdocumentduplicatesresponse import (
        ListDocumentDuplicatesResponse,
        ListDocumentDuplicatesResponseTypedDict,
    )
    from .listdocumentpoliciesop import (
        ListDocumentPoliciesRequest,
        ListDocumentPoliciesRequestTypedDict,
        ListDocumentPoliciesResponseResponse,
        ListDocumentPoliciesResponseResponseTypedDict,
    )
    from .listdocumentpoliciesresponse import (
        ListDocumentPoliciesResponse,
        ListDocumentPoliciesResponseTypedDict,
    )
    from .listdocumentsop import (
        ListDocumentsRequest,
        ListDocumentsRequestTypedDict,
        ListDocumentsResponseResponse,
        ListDocumentsResponseResponseTypedDict,
    )
    from .listdocumentsresponse import (
        ListDocumentsResponse,
        ListDocumentsResponseTypedDict,
    )
    from .listdocumentversionsop import (
        ListDocumentVersionsRequest,
        ListDocumentVersionsRequestTypedDict,
        ListDocumentVersionsResponse,
        ListDocumentVersionsResponseTypedDict,
    )
    from .listorganizationinvitesop import (
        ListOrganizationInvitesRequest,
        ListOrganizationInvitesRequestTypedDict,
        ListOrganizationInvitesResponseResponse,
        ListOrganizationInvitesResponseResponseTypedDict,
    )
    from .listorganizationinvitesresponse import (
        ListOrganizationInvitesResponse,
        ListOrganizationInvitesResponseTypedDict,
    )
    from .listorganizationmembersop import (
        ListOrganizationMembersRequest,
        ListOrganizationMembersRequestTypedDict,
        ListOrganizationMembersResponseResponse,
        ListOrganizationMembersResponseResponseTypedDict,
    )
    from .listorganizationmembersresponse import (
        ListOrganizationMembersResponse,
        ListOrganizationMembersResponseTypedDict,
    )
    from .listorganizationsop import (
        ListOrganizationsRequest,
        ListOrganizationsRequestTypedDict,
        ListOrganizationsResponseResponse,
        ListOrganizationsResponseResponseTypedDict,
    )
    from .listorganizationsresponse import (
        ListOrganizationsResponse,
        ListOrganizationsResponseTypedDict,
    )
    from .listversionsresponse import (
        ListVersionsResponse,
        ListVersionsResponseTypedDict,
    )
    from .organization import Organization, OrganizationTypedDict
    from .organizationinvite import OrganizationInvite, OrganizationInviteTypedDict
    from .organizationinvitestatus import OrganizationInviteStatus
    from .organizationmember import OrganizationMember, OrganizationMemberTypedDict
    from .organizationquota import OrganizationQuota, OrganizationQuotaTypedDict
    from .organizationrole import OrganizationRole
    from .pagination import Pagination, PaginationTypedDict
    from .policy import Policy, PolicyTypedDict
    from .processdocumentop import (
        ProcessDocumentProcessDocumentRequest,
        ProcessDocumentProcessDocumentRequestTypedDict,
        ProcessDocumentRequest,
        ProcessDocumentRequestTypedDict,
        ProcessDocumentResponseResponse,
        ProcessDocumentResponseResponseTypedDict,
    )
    from .processdocumentresponse import (
        ProcessDocumentResponse,
        ProcessDocumentResponseTypedDict,
    )
    from .processingoutcome import ProcessingOutcome
    from .processingstatus import ProcessingStatus
    from .quotatier import QuotaTier
    from .recipient import Recipient, RecipientTypedDict
    from .recipientgrant import RecipientGrant, RecipientGrantTypedDict
    from .recipienttype import RecipientType
    from .removeorganizationmemberop import (
        RemoveOrganizationMemberRequest,
        RemoveOrganizationMemberRequestTypedDict,
        RemoveOrganizationMemberResponseResponse,
        RemoveOrganizationMemberResponseResponseTypedDict,
    )
    from .removeorganizationmemberresponse import (
        RemoveOrganizationMemberResponse,
        RemoveOrganizationMemberResponseTypedDict,
    )
    from .resendorganizationinviteop import (
        ResendOrganizationInviteRequest,
        ResendOrganizationInviteRequestTypedDict,
        ResendOrganizationInviteResendOrganizationInviteRequest,
        ResendOrganizationInviteResendOrganizationInviteRequestTypedDict,
        ResendOrganizationInviteResponseResponse,
        ResendOrganizationInviteResponseResponseTypedDict,
    )
    from .resendorganizationinviteresponse import (
        ResendOrganizationInviteResponse,
        ResendOrganizationInviteResponseTypedDict,
    )
    from .revokeapikeyop import (
        RevokeAPIKeyRequest,
        RevokeAPIKeyRequestTypedDict,
        RevokeAPIKeyResponseResponse,
        RevokeAPIKeyResponseResponseTypedDict,
        RevokeAPIKeyRevokeAPIKeyRequest,
        RevokeAPIKeyRevokeAPIKeyRequestTypedDict,
    )
    from .revokeapikeyresponse import (
        RevokeAPIKeyResponse,
        RevokeAPIKeyResponseTypedDict,
    )
    from .revokedocumentaccessop import (
        RevokeDocumentAccessRequest,
        RevokeDocumentAccessRequestTypedDict,
        RevokeDocumentAccessResponseResponse,
        RevokeDocumentAccessResponseResponseTypedDict,
    )
    from .revokedocumentaccessresponse import (
        RevokeDocumentAccessResponse,
        RevokeDocumentAccessResponseTypedDict,
    )
    from .revokeorganizationinviteop import (
        RevokeOrganizationInviteRequest,
        RevokeOrganizationInviteRequestTypedDict,
        RevokeOrganizationInviteResponseResponse,
        RevokeOrganizationInviteResponseResponseTypedDict,
        RevokeOrganizationInviteRevokeOrganizationInviteRequest,
        RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict,
    )
    from .revokeorganizationinviteresponse import (
        RevokeOrganizationInviteResponse,
        RevokeOrganizationInviteResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .setapikeyquotaop import (
        SetAPIKeyQuotaRequest,
        SetAPIKeyQuotaRequestTypedDict,
        SetAPIKeyQuotaResponseResponse,
        SetAPIKeyQuotaResponseResponseTypedDict,
        SetAPIKeyQuotaSetAPIKeyQuotaRequest,
        SetAPIKeyQuotaSetAPIKeyQuotaRequestTypedDict,
    )
    from .setapikeyquotaresponse import (
        SetAPIKeyQuotaResponse,
        SetAPIKeyQuotaResponseTypedDict,
    )
    from .setgeneralaccessop import (
        SetGeneralAccessRequest,
        SetGeneralAccessRequestTypedDict,
        SetGeneralAccessResponseResponse,
        SetGeneralAccessResponseResponseTypedDict,
        SetGeneralAccessSetGeneralAccessRequest,
        SetGeneralAccessSetGeneralAccessRequestTypedDict,
    )
    from .setgeneralaccessresponse import (
        SetGeneralAccessResponse,
        SetGeneralAccessResponseTypedDict,
    )
    from .sharelink import ShareLink, ShareLinkTypedDict
    from .subject import Subject, SubjectTypedDict
    from .subjecttype import SubjectType
    from .timelineevent import TimelineEvent, TimelineEventTypedDict
    from .timelineeventtype import TimelineEventType
    from .transferdocumentownershipop import (
        TransferDocumentOwnershipRequest,
        TransferDocumentOwnershipRequestTypedDict,
        TransferDocumentOwnershipResponseResponse,
        TransferDocumentOwnershipResponseResponseTypedDict,
        TransferDocumentOwnershipTransferDocumentOwnershipRequest,
        TransferDocumentOwnershipTransferDocumentOwnershipRequestTypedDict,
    )
    from .transferdocumentownershipresponse import (
        TransferDocumentOwnershipResponse,
        TransferDocumentOwnershipResponseTypedDict,
    )
    from .trashdocumentop import (
        TrashDocumentRequest,
        TrashDocumentRequestTypedDict,
        TrashDocumentResponseResponse,
        TrashDocumentResponseResponseTypedDict,
        TrashDocumentTrashDocumentRequest,
        TrashDocumentTrashDocumentRequestTypedDict,
    )
    from .trashdocumentresponse import (
        TrashDocumentResponse,
        TrashDocumentResponseTypedDict,
    )
    from .untrashdocumentop import (
        UntrashDocumentRequest,
        UntrashDocumentRequestTypedDict,
        UntrashDocumentResponseResponse,
        UntrashDocumentResponseResponseTypedDict,
        UntrashDocumentUntrashDocumentRequest,
        UntrashDocumentUntrashDocumentRequestTypedDict,
    )
    from .untrashdocumentresponse import (
        UntrashDocumentResponse,
        UntrashDocumentResponseTypedDict,
    )
    from .updatedocumentaccessop import (
        UpdateDocumentAccessRequest,
        UpdateDocumentAccessRequestTypedDict,
        UpdateDocumentAccessResponseResponse,
        UpdateDocumentAccessResponseResponseTypedDict,
        UpdateDocumentAccessUpdateDocumentAccessRequest,
        UpdateDocumentAccessUpdateDocumentAccessRequestTypedDict,
    )
    from .updatedocumentaccessresponse import (
        UpdateDocumentAccessResponse,
        UpdateDocumentAccessResponseTypedDict,
    )
    from .updatedocumentop import (
        UpdateDocumentRequest,
        UpdateDocumentRequestTypedDict,
        UpdateDocumentResponseResponse,
        UpdateDocumentResponseResponseTypedDict,
        UpdateDocumentUpdateDocumentRequest,
        UpdateDocumentUpdateDocumentRequestTypedDict,
    )
    from .updatedocumentresponse import (
        UpdateDocumentResponse,
        UpdateDocumentResponseTypedDict,
    )
    from .updateorganizationmemberop import (
        UpdateOrganizationMemberRequest,
        UpdateOrganizationMemberRequestTypedDict,
        UpdateOrganizationMemberResponseResponse,
        UpdateOrganizationMemberResponseResponseTypedDict,
        UpdateOrganizationMemberUpdateOrganizationMemberRequest,
        UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict,
    )
    from .updateorganizationmemberresponse import (
        UpdateOrganizationMemberResponse,
        UpdateOrganizationMemberResponseTypedDict,
    )
    from .updateorganizationop import (
        UpdateOrganizationRequest,
        UpdateOrganizationRequestTypedDict,
        UpdateOrganizationResponseResponse,
        UpdateOrganizationResponseResponseTypedDict,
        UpdateOrganizationUpdateOrganizationRequest,
        UpdateOrganizationUpdateOrganizationRequestTypedDict,
    )
    from .updateorganizationresponse import (
        UpdateOrganizationResponse,
        UpdateOrganizationResponseTypedDict,
    )
    from .updateversionop import (
        UpdateVersionRequest,
        UpdateVersionRequestTypedDict,
        UpdateVersionResponse,
        UpdateVersionResponseTypedDict,
        UpdateVersionUpdateVersionRequest,
        UpdateVersionUpdateVersionRequestTypedDict,
    )
    from .user import User, UserTypedDict
    from .value import Value, ValueTypedDict
    from .version import Version, VersionTypedDict
    from .versionref import VersionRef, VersionRefTypedDict

__all__ = [
    "APIKey",
    "APIKeyQuota",
    "APIKeyQuotaTypedDict",
    "APIKeyTypedDict",
    "AcceptOrganizationInviteAcceptOrganizationInviteRequest",
    "AcceptOrganizationInviteAcceptOrganizationInviteRequestTypedDict",
    "AcceptOrganizationInviteRequest",
    "AcceptOrganizationInviteRequestTypedDict",
    "AcceptOrganizationInviteResponse",
    "AcceptOrganizationInviteResponseResponse",
    "AcceptOrganizationInviteResponseResponseTypedDict",
    "AcceptOrganizationInviteResponseTypedDict",
    "AccessGrantResult",
    "AccessGrantResultTypedDict",
    "AccessLevel",
    "AccessRequest",
    "AccessRequestPermission",
    "AccessRequestStatus",
    "AccessRequestTypedDict",
    "AddOrganizationMemberAddOrganizationMemberRequest",
    "AddOrganizationMemberAddOrganizationMemberRequestTypedDict",
    "AddOrganizationMemberRequest",
    "AddOrganizationMemberRequestTypedDict",
    "AddOrganizationMemberResponse",
    "AddOrganizationMemberResponseResponse",
    "AddOrganizationMemberResponseResponseTypedDict",
    "AddOrganizationMemberResponseTypedDict",
    "ApproveAccessRequestApproveAccessRequestRequest",
    "ApproveAccessRequestApproveAccessRequestRequestTypedDict",
    "ApproveAccessRequestRequest",
    "ApproveAccessRequestRequestTypedDict",
    "ApproveAccessRequestResponse",
    "ApproveAccessRequestResponseResponse",
    "ApproveAccessRequestResponseResponseTypedDict",
    "ApproveAccessRequestResponseTypedDict",
    "AttachDocumentPolicyRequest",
    "AttachDocumentPolicyRequestTypedDict",
    "AttachDocumentPolicyResponse",
    "AttachDocumentPolicyResponseTypedDict",
    "AttachPolicyRequest",
    "AttachPolicyRequestTypedDict",
    "CheckAccessRequestStatusRequest",
    "CheckAccessRequestStatusRequestTypedDict",
    "CheckAccessRequestStatusResponse",
    "CheckAccessRequestStatusResponseResponse",
    "CheckAccessRequestStatusResponseResponseTypedDict",
    "CheckAccessRequestStatusResponseTypedDict",
    "Code",
    "CreateAPIKeyRequest",
    "CreateAPIKeyRequestTypedDict",
    "CreateAPIKeyResponse",
    "CreateAPIKeyResponseResponse",
    "CreateAPIKeyResponseResponseTypedDict",
    "CreateAPIKeyResponseTypedDict",
    "CreateAccessRequestCreateAccessRequestRequest",
    "CreateAccessRequestCreateAccessRequestRequestTypedDict",
    "CreateAccessRequestRequest",
    "CreateAccessRequestRequestTypedDict",
    "CreateAccessRequestResponse",
    "CreateAccessRequestResponseResponse",
    "CreateAccessRequestResponseResponseTypedDict",
    "CreateAccessRequestResponseTypedDict",
    "CreateDocumentRequest",
    "CreateDocumentRequestPayload",
    "CreateDocumentRequestPayloadTypedDict",
    "CreateDocumentRequestTypedDict",
    "CreateDocumentResponse",
    "CreateDocumentResponseResponse",
    "CreateDocumentResponseResponseTypedDict",
    "CreateDocumentResponseTypedDict",
    "CreateDocumentVersionRequest",
    "CreateDocumentVersionRequestTypedDict",
    "CreateDocumentVersionResponse",
    "CreateDocumentVersionResponseTypedDict",
    "CreateOrganizationInviteCreateOrganizationInviteRequest",
    "CreateOrganizationInviteCreateOrganizationInviteRequestTypedDict",
    "CreateOrganizationInviteRequest",
    "CreateOrganizationInviteRequestTypedDict",
    "CreateOrganizationInviteResponse",
    "CreateOrganizationInviteResponseResponse",
    "CreateOrganizationInviteResponseResponseTypedDict",
    "CreateOrganizationInviteResponseTypedDict",
    "CreateShareLinkCreateShareLinkRequest",
    "CreateShareLinkCreateShareLinkRequestTypedDict",
    "CreateShareLinkRequest",
    "CreateShareLinkRequestTypedDict",
    "CreateShareLinkResponse",
    "CreateShareLinkResponseResponse",
    "CreateShareLinkResponseResponseTypedDict",
    "CreateShareLinkResponseTypedDict",
    "CreateVersionRequest",
    "CreateVersionRequestPayload",
    "CreateVersionRequestPayloadTypedDict",
    "CreateVersionRequestTypedDict",
    "DailyUsage",
    "DailyUsageTypedDict",
    "DeleteAPIKeyQuotaRequest",
    "DeleteAPIKeyQuotaRequestTypedDict",
    "DeleteAPIKeyQuotaResponse",
    "DeleteAPIKeyQuotaResponseResponse",
    "DeleteAPIKeyQuotaResponseResponseTypedDict",
    "DeleteAPIKeyQuotaResponseTypedDict",
    "DenyAccessRequestDenyAccessRequestRequest",
    "DenyAccessRequestDenyAccessRequestRequestTypedDict",
    "DenyAccessRequestRequest",
    "DenyAccessRequestRequestTypedDict",
    "DenyAccessRequestResponse",
    "DenyAccessRequestResponseResponse",
    "DenyAccessRequestResponseResponseTypedDict",
    "DenyAccessRequestResponseTypedDict",
    "DetachDocumentPolicyRequest",
    "DetachDocumentPolicyRequestTypedDict",
    "DetachDocumentPolicyResponse",
    "DetachDocumentPolicyResponseTypedDict",
    "Document",
    "DocumentOwnership",
    "DocumentPermissionSet",
    "DocumentPermissionSetTypedDict",
    "DocumentPolicy",
    "DocumentPolicyTypedDict",
    "DocumentRole",
    "DocumentTrashState",
    "DocumentTypedDict",
    "DuplicateDocument",
    "DuplicateDocumentTypedDict",
    "Empty",
    "EmptyTypedDict",
    "ErrorDetail",
    "ErrorDetailTypedDict",
    "ExportDocumentRequest",
    "ExportDocumentRequestTypedDict",
    "ExportDocumentResponse",
    "ExportDocumentResponseResponse",
    "ExportDocumentResponseResponseTypedDict",
    "ExportDocumentResponseTypedDict",
    "GeneralAccessLevel",
    "GenerateDocumentEntryPageRequest",
    "GenerateDocumentEntryPageRequestTypedDict",
    "GenerateDocumentEntryPageResponse",
    "GenerateDocumentEntryPageResponseTypedDict",
    "GenerateEntryPageResponse",
    "GenerateEntryPageResponseTypedDict",
    "GetDocumentQuotaResponse",
    "GetDocumentQuotaResponseResponse",
    "GetDocumentQuotaResponseResponseTypedDict",
    "GetDocumentQuotaResponseTypedDict",
    "GetDocumentRequest",
    "GetDocumentRequestTypedDict",
    "GetDocumentResponse",
    "GetDocumentResponseResponse",
    "GetDocumentResponseResponseTypedDict",
    "GetDocumentResponseTypedDict",
    "GetDocumentTimelineRequest",
    "GetDocumentTimelineRequestTypedDict",
    "GetDocumentTimelineResponse",
    "GetDocumentTimelineResponseTypedDict",
    "GetGeneralAccessRequest",
    "GetGeneralAccessRequestTypedDict",
    "GetGeneralAccessResponse",
    "GetGeneralAccessResponseResponse",
    "GetGeneralAccessResponseResponseTypedDict",
    "GetGeneralAccessResponseTypedDict",
    "GetMeResponse",
    "GetMeResponseResponse",
    "GetMeResponseResponseTypedDict",
    "GetMeResponseTypedDict",
    "GetOrganizationQuotaRequest",
    "GetOrganizationQuotaRequestTypedDict",
    "GetOrganizationQuotaResponse",
    "GetOrganizationQuotaResponseResponse",
    "GetOrganizationQuotaResponseResponseTypedDict",
    "GetOrganizationQuotaResponseTypedDict",
    "GetOrganizationRequest",
    "GetOrganizationRequestTypedDict",
    "GetOrganizationResponse",
    "GetOrganizationResponseResponse",
    "GetOrganizationResponseResponseTypedDict",
    "GetOrganizationResponseTypedDict",
    "GetTimelineResponse",
    "GetTimelineResponseTypedDict",
    "GetUsageHistoryRequest",
    "GetUsageHistoryRequestTypedDict",
    "GetUsageHistoryResponse",
    "GetUsageHistoryResponseResponse",
    "GetUsageHistoryResponseResponseTypedDict",
    "GetUsageHistoryResponseTypedDict",
    "GetUserPreferencesResponse",
    "GetUserPreferencesResponseResponse",
    "GetUserPreferencesResponseResponseTypedDict",
    "GetUserPreferencesResponseTypedDict",
    "GetVersionRequest",
    "GetVersionRequestTypedDict",
    "GetVersionResponse",
    "GetVersionResponseTypedDict",
    "GrantDocumentAccessGrantDocumentAccessRequest",
    "GrantDocumentAccessGrantDocumentAccessRequestTypedDict",
    "GrantDocumentAccessRequest",
    "GrantDocumentAccessRequestTypedDict",
    "GrantDocumentAccessResponse",
    "GrantDocumentAccessResponseResponse",
    "GrantDocumentAccessResponseResponseTypedDict",
    "GrantDocumentAccessResponseTypedDict",
    "InspectAccessResponse",
    "InspectAccessResponseTypedDict",
    "InspectDocumentAccessRequest",
    "InspectDocumentAccessRequestTypedDict",
    "InspectDocumentAccessResponse",
    "InspectDocumentAccessResponseTypedDict",
    "ListAPIKeyQuotasRequest",
    "ListAPIKeyQuotasRequestTypedDict",
    "ListAPIKeyQuotasResponse",
    "ListAPIKeyQuotasResponseResponse",
    "ListAPIKeyQuotasResponseResponseTypedDict",
    "ListAPIKeyQuotasResponseTypedDict",
    "ListAPIKeysRequest",
    "ListAPIKeysRequestTypedDict",
    "ListAPIKeysResponse",
    "ListAPIKeysResponseResponse",
    "ListAPIKeysResponseResponseTypedDict",
    "ListAPIKeysResponseTypedDict",
    "ListAccessRequestsRequest",
    "ListAccessRequestsRequestTypedDict",
    "ListAccessRequestsResponse",
    "ListAccessRequestsResponseResponse",
    "ListAccessRequestsResponseResponseTypedDict",
    "ListAccessRequestsResponseTypedDict",
    "ListDocumentAccessRequest",
    "ListDocumentAccessRequestTypedDict",
    "ListDocumentAccessResponse",
    "ListDocumentAccessResponseResponse",
    "ListDocumentAccessResponseResponseTypedDict",
    "ListDocumentAccessResponseTypedDict",
    "ListDocumentDuplicatesRequest",
    "ListDocumentDuplicatesRequestTypedDict",
    "ListDocumentDuplicatesResponse",
    "ListDocumentDuplicatesResponseResponse",
    "ListDocumentDuplicatesResponseResponseTypedDict",
    "ListDocumentDuplicatesResponseTypedDict",
    "ListDocumentPoliciesRequest",
    "ListDocumentPoliciesRequestTypedDict",
    "ListDocumentPoliciesResponse",
    "ListDocumentPoliciesResponseResponse",
    "ListDocumentPoliciesResponseResponseTypedDict",
    "ListDocumentPoliciesResponseTypedDict",
    "ListDocumentVersionsRequest",
    "ListDocumentVersionsRequestTypedDict",
    "ListDocumentVersionsResponse",
    "ListDocumentVersionsResponseTypedDict",
    "ListDocumentsRequest",
    "ListDocumentsRequestTypedDict",
    "ListDocumentsResponse",
    "ListDocumentsResponseResponse",
    "ListDocumentsResponseResponseTypedDict",
    "ListDocumentsResponseTypedDict",
    "ListOrganizationInvitesRequest",
    "ListOrganizationInvitesRequestTypedDict",
    "ListOrganizationInvitesResponse",
    "ListOrganizationInvitesResponseResponse",
    "ListOrganizationInvitesResponseResponseTypedDict",
    "ListOrganizationInvitesResponseTypedDict",
    "ListOrganizationMembersRequest",
    "ListOrganizationMembersRequestTypedDict",
    "ListOrganizationMembersResponse",
    "ListOrganizationMembersResponseResponse",
    "ListOrganizationMembersResponseResponseTypedDict",
    "ListOrganizationMembersResponseTypedDict",
    "ListOrganizationsRequest",
    "ListOrganizationsRequestTypedDict",
    "ListOrganizationsResponse",
    "ListOrganizationsResponseResponse",
    "ListOrganizationsResponseResponseTypedDict",
    "ListOrganizationsResponseTypedDict",
    "ListVersionsResponse",
    "ListVersionsResponseTypedDict",
    "Organization",
    "OrganizationInvite",
    "OrganizationInviteStatus",
    "OrganizationInviteTypedDict",
    "OrganizationMember",
    "OrganizationMemberTypedDict",
    "OrganizationQuota",
    "OrganizationQuotaTypedDict",
    "OrganizationRole",
    "OrganizationTypedDict",
    "Pagination",
    "PaginationTypedDict",
    "Policy",
    "PolicyTypedDict",
    "ProcessDocumentProcessDocumentRequest",
    "ProcessDocumentProcessDocumentRequestTypedDict",
    "ProcessDocumentRequest",
    "ProcessDocumentRequestTypedDict",
    "ProcessDocumentResponse",
    "ProcessDocumentResponseResponse",
    "ProcessDocumentResponseResponseTypedDict",
    "ProcessDocumentResponseTypedDict",
    "ProcessingOutcome",
    "ProcessingStatus",
    "QuotaTier",
    "Reason",
    "Recipient",
    "RecipientGrant",
    "RecipientGrantTypedDict",
    "RecipientType",
    "RecipientTypedDict",
    "RemoveOrganizationMemberRequest",
    "RemoveOrganizationMemberRequestTypedDict",
    "RemoveOrganizationMemberResponse",
    "RemoveOrganizationMemberResponseResponse",
    "RemoveOrganizationMemberResponseResponseTypedDict",
    "RemoveOrganizationMemberResponseTypedDict",
    "ResendOrganizationInviteRequest",
    "ResendOrganizationInviteRequestTypedDict",
    "ResendOrganizationInviteResendOrganizationInviteRequest",
    "ResendOrganizationInviteResendOrganizationInviteRequestTypedDict",
    "ResendOrganizationInviteResponse",
    "ResendOrganizationInviteResponseResponse",
    "ResendOrganizationInviteResponseResponseTypedDict",
    "ResendOrganizationInviteResponseTypedDict",
    "RevokeAPIKeyRequest",
    "RevokeAPIKeyRequestTypedDict",
    "RevokeAPIKeyResponse",
    "RevokeAPIKeyResponseResponse",
    "RevokeAPIKeyResponseResponseTypedDict",
    "RevokeAPIKeyResponseTypedDict",
    "RevokeAPIKeyRevokeAPIKeyRequest",
    "RevokeAPIKeyRevokeAPIKeyRequestTypedDict",
    "RevokeDocumentAccessRequest",
    "RevokeDocumentAccessRequestTypedDict",
    "RevokeDocumentAccessResponse",
    "RevokeDocumentAccessResponseResponse",
    "RevokeDocumentAccessResponseResponseTypedDict",
    "RevokeDocumentAccessResponseTypedDict",
    "RevokeOrganizationInviteRequest",
    "RevokeOrganizationInviteRequestTypedDict",
    "RevokeOrganizationInviteResponse",
    "RevokeOrganizationInviteResponseResponse",
    "RevokeOrganizationInviteResponseResponseTypedDict",
    "RevokeOrganizationInviteResponseTypedDict",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequest",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict",
    "Security",
    "SecurityTypedDict",
    "SetAPIKeyQuotaRequest",
    "SetAPIKeyQuotaRequestTypedDict",
    "SetAPIKeyQuotaResponse",
    "SetAPIKeyQuotaResponseResponse",
    "SetAPIKeyQuotaResponseResponseTypedDict",
    "SetAPIKeyQuotaResponseTypedDict",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequest",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequestTypedDict",
    "SetGeneralAccessRequest",
    "SetGeneralAccessRequestTypedDict",
    "SetGeneralAccessResponse",
    "SetGeneralAccessResponseResponse",
    "SetGeneralAccessResponseResponseTypedDict",
    "SetGeneralAccessResponseTypedDict",
    "SetGeneralAccessSetGeneralAccessRequest",
    "SetGeneralAccessSetGeneralAccessRequestTypedDict",
    "ShareLink",
    "ShareLinkTypedDict",
    "Subject",
    "SubjectType",
    "SubjectTypedDict",
    "TimelineEvent",
    "TimelineEventType",
    "TimelineEventTypedDict",
    "TransferDocumentOwnershipRequest",
    "TransferDocumentOwnershipRequestTypedDict",
    "TransferDocumentOwnershipResponse",
    "TransferDocumentOwnershipResponseResponse",
    "TransferDocumentOwnershipResponseResponseTypedDict",
    "TransferDocumentOwnershipResponseTypedDict",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequest",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequestTypedDict",
    "TrashDocumentRequest",
    "TrashDocumentRequestTypedDict",
    "TrashDocumentResponse",
    "TrashDocumentResponseResponse",
    "TrashDocumentResponseResponseTypedDict",
    "TrashDocumentResponseTypedDict",
    "TrashDocumentTrashDocumentRequest",
    "TrashDocumentTrashDocumentRequestTypedDict",
    "UntrashDocumentRequest",
    "UntrashDocumentRequestTypedDict",
    "UntrashDocumentResponse",
    "UntrashDocumentResponseResponse",
    "UntrashDocumentResponseResponseTypedDict",
    "UntrashDocumentResponseTypedDict",
    "UntrashDocumentUntrashDocumentRequest",
    "UntrashDocumentUntrashDocumentRequestTypedDict",
    "UpdateDocumentAccessRequest",
    "UpdateDocumentAccessRequestTypedDict",
    "UpdateDocumentAccessResponse",
    "UpdateDocumentAccessResponseResponse",
    "UpdateDocumentAccessResponseResponseTypedDict",
    "UpdateDocumentAccessResponseTypedDict",
    "UpdateDocumentAccessUpdateDocumentAccessRequest",
    "UpdateDocumentAccessUpdateDocumentAccessRequestTypedDict",
    "UpdateDocumentRequest",
    "UpdateDocumentRequestTypedDict",
    "UpdateDocumentResponse",
    "UpdateDocumentResponseResponse",
    "UpdateDocumentResponseResponseTypedDict",
    "UpdateDocumentResponseTypedDict",
    "UpdateDocumentUpdateDocumentRequest",
    "UpdateDocumentUpdateDocumentRequestTypedDict",
    "UpdateOrganizationMemberRequest",
    "UpdateOrganizationMemberRequestTypedDict",
    "UpdateOrganizationMemberResponse",
    "UpdateOrganizationMemberResponseResponse",
    "UpdateOrganizationMemberResponseResponseTypedDict",
    "UpdateOrganizationMemberResponseTypedDict",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequest",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict",
    "UpdateOrganizationRequest",
    "UpdateOrganizationRequestTypedDict",
    "UpdateOrganizationResponse",
    "UpdateOrganizationResponseResponse",
    "UpdateOrganizationResponseResponseTypedDict",
    "UpdateOrganizationResponseTypedDict",
    "UpdateOrganizationUpdateOrganizationRequest",
    "UpdateOrganizationUpdateOrganizationRequestTypedDict",
    "UpdateVersionRequest",
    "UpdateVersionRequestTypedDict",
    "UpdateVersionResponse",
    "UpdateVersionResponseTypedDict",
    "UpdateVersionUpdateVersionRequest",
    "UpdateVersionUpdateVersionRequestTypedDict",
    "User",
    "UserTypedDict",
    "Value",
    "ValueTypedDict",
    "Version",
    "VersionRef",
    "VersionRefTypedDict",
    "VersionTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AcceptOrganizationInviteAcceptOrganizationInviteRequest": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteAcceptOrganizationInviteRequestTypedDict": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteRequest": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteRequestTypedDict": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteResponseResponse": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteResponseResponseTypedDict": ".acceptorganizationinviteop",
    "AcceptOrganizationInviteResponse": ".acceptorganizationinviteresponse",
    "AcceptOrganizationInviteResponseTypedDict": ".acceptorganizationinviteresponse",
    "AccessGrantResult": ".accessgrantresult",
    "AccessGrantResultTypedDict": ".accessgrantresult",
    "AccessLevel": ".accesslevel",
    "AccessRequest": ".accessrequest",
    "AccessRequestTypedDict": ".accessrequest",
    "AccessRequestPermission": ".accessrequestpermission",
    "AccessRequestStatus": ".accessrequeststatus",
    "AddOrganizationMemberAddOrganizationMemberRequest": ".addorganizationmemberop",
    "AddOrganizationMemberAddOrganizationMemberRequestTypedDict": ".addorganizationmemberop",
    "AddOrganizationMemberRequest": ".addorganizationmemberop",
    "AddOrganizationMemberRequestTypedDict": ".addorganizationmemberop",
    "AddOrganizationMemberResponseResponse": ".addorganizationmemberop",
    "AddOrganizationMemberResponseResponseTypedDict": ".addorganizationmemberop",
    "AddOrganizationMemberResponse": ".addorganizationmemberresponse",
    "AddOrganizationMemberResponseTypedDict": ".addorganizationmemberresponse",
    "APIKey": ".apikey",
    "APIKeyTypedDict": ".apikey",
    "APIKeyQuota": ".apikeyquota",
    "APIKeyQuotaTypedDict": ".apikeyquota",
    "ApproveAccessRequestApproveAccessRequestRequest": ".approveaccessrequestop",
    "ApproveAccessRequestApproveAccessRequestRequestTypedDict": ".approveaccessrequestop",
    "ApproveAccessRequestRequest": ".approveaccessrequestop",
    "ApproveAccessRequestRequestTypedDict": ".approveaccessrequestop",
    "ApproveAccessRequestResponseResponse": ".approveaccessrequestop",
    "ApproveAccessRequestResponseResponseTypedDict": ".approveaccessrequestop",
    "ApproveAccessRequestResponse": ".approveaccessrequestresponse",
    "ApproveAccessRequestResponseTypedDict": ".approveaccessrequestresponse",
    "AttachDocumentPolicyRequest": ".attachdocumentpolicyop",
    "AttachDocumentPolicyRequestTypedDict": ".attachdocumentpolicyop",
    "AttachDocumentPolicyResponse": ".attachdocumentpolicyop",
    "AttachDocumentPolicyResponseTypedDict": ".attachdocumentpolicyop",
    "AttachPolicyRequest": ".attachdocumentpolicyop",
    "AttachPolicyRequestTypedDict": ".attachdocumentpolicyop",
    "CheckAccessRequestStatusRequest": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusRequestTypedDict": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusResponseResponse": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusResponseResponseTypedDict": ".checkaccessrequeststatusop",
    "CheckAccessRequestStatusResponse": ".checkaccessrequeststatusresponse",
    "CheckAccessRequestStatusResponseTypedDict": ".checkaccessrequeststatusresponse",
    "CreateAccessRequestCreateAccessRequestRequest": ".createaccessrequestop",
    "CreateAccessRequestCreateAccessRequestRequestTypedDict": ".createaccessrequestop",
    "CreateAccessRequestRequest": ".createaccessrequestop",
    "CreateAccessRequestRequestTypedDict": ".createaccessrequestop",
    "CreateAccessRequestResponseResponse": ".createaccessrequestop",
    "CreateAccessRequestResponseResponseTypedDict": ".createaccessrequestop",
    "CreateAccessRequestResponse": ".createaccessrequestresponse",
    "CreateAccessRequestResponseTypedDict": ".createaccessrequestresponse",
    "CreateAPIKeyResponseResponse": ".createapikeyop",
    "CreateAPIKeyResponseResponseTypedDict": ".createapikeyop",
    "CreateAPIKeyRequest": ".createapikeyrequest",
    "CreateAPIKeyRequestTypedDict": ".createapikeyrequest",
    "CreateAPIKeyResponse": ".createapikeyresponse",
    "CreateAPIKeyResponseTypedDict": ".createapikeyresponse",
    "CreateDocumentResponseResponse": ".createdocumentop",
    "CreateDocumentResponseResponseTypedDict": ".createdocumentop",
    "CreateDocumentRequest": ".createdocumentrequest",
    "CreateDocumentRequestPayload": ".createdocumentrequest",
    "CreateDocumentRequestPayloadTypedDict": ".createdocumentrequest",
    "CreateDocumentRequestTypedDict": ".createdocumentrequest",
    "CreateDocumentResponse": ".createdocumentresponse",
    "CreateDocumentResponseTypedDict": ".createdocumentresponse",
    "CreateDocumentVersionRequest": ".createdocumentversionop",
    "CreateDocumentVersionRequestTypedDict": ".createdocumentversionop",
    "CreateDocumentVersionResponse": ".createdocumentversionop",
    "CreateDocumentVersionResponseTypedDict": ".createdocumentversionop",
    "CreateOrganizationInviteCreateOrganizationInviteRequest": ".createorganizationinviteop",
    "CreateOrganizationInviteCreateOrganizationInviteRequestTypedDict": ".createorganizationinviteop",
    "CreateOrganizationInviteRequest": ".createorganizationinviteop",
    "CreateOrganizationInviteRequestTypedDict": ".createorganizationinviteop",
    "CreateOrganizationInviteResponseResponse": ".createorganizationinviteop",
    "CreateOrganizationInviteResponseResponseTypedDict": ".createorganizationinviteop",
    "CreateOrganizationInviteResponse": ".createorganizationinviteresponse",
    "CreateOrganizationInviteResponseTypedDict": ".createorganizationinviteresponse",
    "CreateShareLinkCreateShareLinkRequest": ".createsharelinkop",
    "CreateShareLinkCreateShareLinkRequestTypedDict": ".createsharelinkop",
    "CreateShareLinkRequest": ".createsharelinkop",
    "CreateShareLinkRequestTypedDict": ".createsharelinkop",
    "CreateShareLinkResponseResponse": ".createsharelinkop",
    "CreateShareLinkResponseResponseTypedDict": ".createsharelinkop",
    "CreateShareLinkResponse": ".createsharelinkresponse",
    "CreateShareLinkResponseTypedDict": ".createsharelinkresponse",
    "CreateVersionRequest": ".createversionrequest",
    "CreateVersionRequestPayload": ".createversionrequest",
    "CreateVersionRequestPayloadTypedDict": ".createversionrequest",
    "CreateVersionRequestTypedDict": ".createversionrequest",
    "DailyUsage": ".dailyusage",
    "DailyUsageTypedDict": ".dailyusage",
    "DeleteAPIKeyQuotaRequest": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaRequestTypedDict": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaResponseResponse": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaResponseResponseTypedDict": ".deleteapikeyquotaop",
    "DeleteAPIKeyQuotaResponse": ".deleteapikeyquotaresponse",
    "DeleteAPIKeyQuotaResponseTypedDict": ".deleteapikeyquotaresponse",
    "DenyAccessRequestDenyAccessRequestRequest": ".denyaccessrequestop",
    "DenyAccessRequestDenyAccessRequestRequestTypedDict": ".denyaccessrequestop",
    "DenyAccessRequestRequest": ".denyaccessrequestop",
    "DenyAccessRequestRequestTypedDict": ".denyaccessrequestop",
    "DenyAccessRequestResponseResponse": ".denyaccessrequestop",
    "DenyAccessRequestResponseResponseTypedDict": ".denyaccessrequestop",
    "DenyAccessRequestResponse": ".denyaccessrequestresponse",
    "DenyAccessRequestResponseTypedDict": ".denyaccessrequestresponse",
    "DetachDocumentPolicyRequest": ".detachdocumentpolicyop",
    "DetachDocumentPolicyRequestTypedDict": ".detachdocumentpolicyop",
    "DetachDocumentPolicyResponse": ".detachdocumentpolicyop",
    "DetachDocumentPolicyResponseTypedDict": ".detachdocumentpolicyop",
    "Document": ".document",
    "DocumentTypedDict": ".document",
    "DocumentOwnership": ".documentownership",
    "DocumentPermissionSet": ".documentpermissionset",
    "DocumentPermissionSetTypedDict": ".documentpermissionset",
    "DocumentPolicy": ".documentpolicy",
    "DocumentPolicyTypedDict": ".documentpolicy",
    "DocumentRole": ".documentrole",
    "DocumentTrashState": ".documenttrashstate",
    "DuplicateDocument": ".duplicatedocument",
    "DuplicateDocumentTypedDict": ".duplicatedocument",
    "Empty": ".empty",
    "EmptyTypedDict": ".empty",
    "ErrorDetail": ".errordetail",
    "ErrorDetailTypedDict": ".errordetail",
    "Reason": ".errordetail",
    "Code": ".errorresponse",
    "ExportDocumentRequest": ".exportdocumentop",
    "ExportDocumentRequestTypedDict": ".exportdocumentop",
    "ExportDocumentResponseResponse": ".exportdocumentop",
    "ExportDocumentResponseResponseTypedDict": ".exportdocumentop",
    "ExportDocumentResponse": ".exportdocumentresponse",
    "ExportDocumentResponseTypedDict": ".exportdocumentresponse",
    "GeneralAccessLevel": ".generalaccesslevel",
    "GenerateDocumentEntryPageRequest": ".generatedocumententrypageop",
    "GenerateDocumentEntryPageRequestTypedDict": ".generatedocumententrypageop",
    "GenerateDocumentEntryPageResponse": ".generatedocumententrypageop",
    "GenerateDocumentEntryPageResponseTypedDict": ".generatedocumententrypageop",
    "GenerateEntryPageResponse": ".generateentrypageresponse",
    "GenerateEntryPageResponseTypedDict": ".generateentrypageresponse",
    "GetDocumentRequest": ".getdocumentop",
    "GetDocumentRequestTypedDict": ".getdocumentop",
    "GetDocumentResponseResponse": ".getdocumentop",
    "GetDocumentResponseResponseTypedDict": ".getdocumentop",
    "GetDocumentQuotaResponseResponse": ".getdocumentquotaop",
    "GetDocumentQuotaResponseResponseTypedDict": ".getdocumentquotaop",
    "GetDocumentQuotaResponse": ".getdocumentquotaresponse",
    "GetDocumentQuotaResponseTypedDict": ".getdocumentquotaresponse",
    "GetDocumentResponse": ".getdocumentresponse",
    "GetDocumentResponseTypedDict": ".getdocumentresponse",
    "GetDocumentTimelineRequest": ".getdocumenttimelineop",
    "GetDocumentTimelineRequestTypedDict": ".getdocumenttimelineop",
    "GetDocumentTimelineResponse": ".getdocumenttimelineop",
    "GetDocumentTimelineResponseTypedDict": ".getdocumenttimelineop",
    "GetGeneralAccessRequest": ".getgeneralaccessop",
    "GetGeneralAccessRequestTypedDict": ".getgeneralaccessop",
    "GetGeneralAccessResponseResponse": ".getgeneralaccessop",
    "GetGeneralAccessResponseResponseTypedDict": ".getgeneralaccessop",
    "GetGeneralAccessResponse": ".getgeneralaccessresponse",
    "GetGeneralAccessResponseTypedDict": ".getgeneralaccessresponse",
    "GetMeResponseResponse": ".getmeop",
    "GetMeResponseResponseTypedDict": ".getmeop",
    "GetMeResponse": ".getmeresponse",
    "GetMeResponseTypedDict": ".getmeresponse",
    "GetOrganizationRequest": ".getorganizationop",
    "GetOrganizationRequestTypedDict": ".getorganizationop",
    "GetOrganizationResponseResponse": ".getorganizationop",
    "GetOrganizationResponseResponseTypedDict": ".getorganizationop",
    "GetOrganizationQuotaRequest": ".getorganizationquotaop",
    "GetOrganizationQuotaRequestTypedDict": ".getorganizationquotaop",
    "GetOrganizationQuotaResponseResponse": ".getorganizationquotaop",
    "GetOrganizationQuotaResponseResponseTypedDict": ".getorganizationquotaop",
    "GetOrganizationQuotaResponse": ".getorganizationquotaresponse",
    "GetOrganizationQuotaResponseTypedDict": ".getorganizationquotaresponse",
    "GetOrganizationResponse": ".getorganizationresponse",
    "GetOrganizationResponseTypedDict": ".getorganizationresponse",
    "GetTimelineResponse": ".gettimelineresponse",
    "GetTimelineResponseTypedDict": ".gettimelineresponse",
    "GetUsageHistoryRequest": ".getusagehistoryop",
    "GetUsageHistoryRequestTypedDict": ".getusagehistoryop",
    "GetUsageHistoryResponseResponse": ".getusagehistoryop",
    "GetUsageHistoryResponseResponseTypedDict": ".getusagehistoryop",
    "GetUsageHistoryResponse": ".getusagehistoryresponse",
    "GetUsageHistoryResponseTypedDict": ".getusagehistoryresponse",
    "GetUserPreferencesResponseResponse": ".getuserpreferencesop",
    "GetUserPreferencesResponseResponseTypedDict": ".getuserpreferencesop",
    "GetUserPreferencesResponse": ".getuserpreferencesresponse",
    "GetUserPreferencesResponseTypedDict": ".getuserpreferencesresponse",
    "GetVersionRequest": ".getversionop",
    "GetVersionRequestTypedDict": ".getversionop",
    "GetVersionResponse": ".getversionop",
    "GetVersionResponseTypedDict": ".getversionop",
    "GrantDocumentAccessGrantDocumentAccessRequest": ".grantdocumentaccessop",
    "GrantDocumentAccessGrantDocumentAccessRequestTypedDict": ".grantdocumentaccessop",
    "GrantDocumentAccessRequest": ".grantdocumentaccessop",
    "GrantDocumentAccessRequestTypedDict": ".grantdocumentaccessop",
    "GrantDocumentAccessResponseResponse": ".grantdocumentaccessop",
    "GrantDocumentAccessResponseResponseTypedDict": ".grantdocumentaccessop",
    "GrantDocumentAccessResponse": ".grantdocumentaccessresponse",
    "GrantDocumentAccessResponseTypedDict": ".grantdocumentaccessresponse",
    "InspectAccessResponse": ".inspectaccessresponse",
    "InspectAccessResponseTypedDict": ".inspectaccessresponse",
    "InspectDocumentAccessRequest": ".inspectdocumentaccessop",
    "InspectDocumentAccessRequestTypedDict": ".inspectdocumentaccessop",
    "InspectDocumentAccessResponse": ".inspectdocumentaccessop",
    "InspectDocumentAccessResponseTypedDict": ".inspectdocumentaccessop",
    "ListAccessRequestsRequest": ".listaccessrequestsop",
    "ListAccessRequestsRequestTypedDict": ".listaccessrequestsop",
    "ListAccessRequestsResponseResponse": ".listaccessrequestsop",
    "ListAccessRequestsResponseResponseTypedDict": ".listaccessrequestsop",
    "ListAccessRequestsResponse": ".listaccessrequestsresponse",
    "ListAccessRequestsResponseTypedDict": ".listaccessrequestsresponse",
    "ListAPIKeyQuotasRequest": ".listapikeyquotasop",
    "ListAPIKeyQuotasRequestTypedDict": ".listapikeyquotasop",
    "ListAPIKeyQuotasResponseResponse": ".listapikeyquotasop",
    "ListAPIKeyQuotasResponseResponseTypedDict": ".listapikeyquotasop",
    "ListAPIKeyQuotasResponse": ".listapikeyquotasresponse",
    "ListAPIKeyQuotasResponseTypedDict": ".listapikeyquotasresponse",
    "ListAPIKeysRequest": ".listapikeysop",
    "ListAPIKeysRequestTypedDict": ".listapikeysop",
    "ListAPIKeysResponseResponse": ".listapikeysop",
    "ListAPIKeysResponseResponseTypedDict": ".listapikeysop",
    "ListAPIKeysResponse": ".listapikeysresponse",
    "ListAPIKeysResponseTypedDict": ".listapikeysresponse",
    "ListDocumentAccessRequest": ".listdocumentaccessop",
    "ListDocumentAccessRequestTypedDict": ".listdocumentaccessop",
    "ListDocumentAccessResponseResponse": ".listdocumentaccessop",
    "ListDocumentAccessResponseResponseTypedDict": ".listdocumentaccessop",
    "ListDocumentAccessResponse": ".listdocumentaccessresponse",
    "ListDocumentAccessResponseTypedDict": ".listdocumentaccessresponse",
    "ListDocumentDuplicatesRequest": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesRequestTypedDict": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesResponseResponse": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesResponseResponseTypedDict": ".listdocumentduplicatesop",
    "ListDocumentDuplicatesResponse": ".listdocumentduplicatesresponse",
    "ListDocumentDuplicatesResponseTypedDict": ".listdocumentduplicatesresponse",
    "ListDocumentPoliciesRequest": ".listdocumentpoliciesop",
    "ListDocumentPoliciesRequestTypedDict": ".listdocumentpoliciesop",
    "ListDocumentPoliciesResponseResponse": ".listdocumentpoliciesop",
    "ListDocumentPoliciesResponseResponseTypedDict": ".listdocumentpoliciesop",
    "ListDocumentPoliciesResponse": ".listdocumentpoliciesresponse",
    "ListDocumentPoliciesResponseTypedDict": ".listdocumentpoliciesresponse",
    "ListDocumentsRequest": ".listdocumentsop",
    "ListDocumentsRequestTypedDict": ".listdocumentsop",
    "ListDocumentsResponseResponse": ".listdocumentsop",
    "ListDocumentsResponseResponseTypedDict": ".listdocumentsop",
    "ListDocumentsResponse": ".listdocumentsresponse",
    "ListDocumentsResponseTypedDict": ".listdocumentsresponse",
    "ListDocumentVersionsRequest": ".listdocumentversionsop",
    "ListDocumentVersionsRequestTypedDict": ".listdocumentversionsop",
    "ListDocumentVersionsResponse": ".listdocumentversionsop",
    "ListDocumentVersionsResponseTypedDict": ".listdocumentversionsop",
    "ListOrganizationInvitesRequest": ".listorganizationinvitesop",
    "ListOrganizationInvitesRequestTypedDict": ".listorganizationinvitesop",
    "ListOrganizationInvitesResponseResponse": ".listorganizationinvitesop",
    "ListOrganizationInvitesResponseResponseTypedDict": ".listorganizationinvitesop",
    "ListOrganizationInvitesResponse": ".listorganizationinvitesresponse",
    "ListOrganizationInvitesResponseTypedDict": ".listorganizationinvitesresponse",
    "ListOrganizationMembersRequest": ".listorganizationmembersop",
    "ListOrganizationMembersRequestTypedDict": ".listorganizationmembersop",
    "ListOrganizationMembersResponseResponse": ".listorganizationmembersop",
    "ListOrganizationMembersResponseResponseTypedDict": ".listorganizationmembersop",
    "ListOrganizationMembersResponse": ".listorganizationmembersresponse",
    "ListOrganizationMembersResponseTypedDict": ".listorganizationmembersresponse",
    "ListOrganizationsRequest": ".listorganizationsop",
    "ListOrganizationsRequestTypedDict": ".listorganizationsop",
    "ListOrganizationsResponseResponse": ".listorganizationsop",
    "ListOrganizationsResponseResponseTypedDict": ".listorganizationsop",
    "ListOrganizationsResponse": ".listorganizationsresponse",
    "ListOrganizationsResponseTypedDict": ".listorganizationsresponse",
    "ListVersionsResponse": ".listversionsresponse",
    "ListVersionsResponseTypedDict": ".listversionsresponse",
    "Organization": ".organization",
    "OrganizationTypedDict": ".organization",
    "OrganizationInvite": ".organizationinvite",
    "OrganizationInviteTypedDict": ".organizationinvite",
    "OrganizationInviteStatus": ".organizationinvitestatus",
    "OrganizationMember": ".organizationmember",
    "OrganizationMemberTypedDict": ".organizationmember",
    "OrganizationQuota": ".organizationquota",
    "OrganizationQuotaTypedDict": ".organizationquota",
    "OrganizationRole": ".organizationrole",
    "Pagination": ".pagination",
    "PaginationTypedDict": ".pagination",
    "Policy": ".policy",
    "PolicyTypedDict": ".policy",
    "ProcessDocumentProcessDocumentRequest": ".processdocumentop",
    "ProcessDocumentProcessDocumentRequestTypedDict": ".processdocumentop",
    "ProcessDocumentRequest": ".processdocumentop",
    "ProcessDocumentRequestTypedDict": ".processdocumentop",
    "ProcessDocumentResponseResponse": ".processdocumentop",
    "ProcessDocumentResponseResponseTypedDict": ".processdocumentop",
    "ProcessDocumentResponse": ".processdocumentresponse",
    "ProcessDocumentResponseTypedDict": ".processdocumentresponse",
    "ProcessingOutcome": ".processingoutcome",
    "ProcessingStatus": ".processingstatus",
    "QuotaTier": ".quotatier",
    "Recipient": ".recipient",
    "RecipientTypedDict": ".recipient",
    "RecipientGrant": ".recipientgrant",
    "RecipientGrantTypedDict": ".recipientgrant",
    "RecipientType": ".recipienttype",
    "RemoveOrganizationMemberRequest": ".removeorganizationmemberop",
    "RemoveOrganizationMemberRequestTypedDict": ".removeorganizationmemberop",
    "RemoveOrganizationMemberResponseResponse": ".removeorganizationmemberop",
    "RemoveOrganizationMemberResponseResponseTypedDict": ".removeorganizationmemberop",
    "RemoveOrganizationMemberResponse": ".removeorganizationmemberresponse",
    "RemoveOrganizationMemberResponseTypedDict": ".removeorganizationmemberresponse",
    "ResendOrganizationInviteRequest": ".resendorganizationinviteop",
    "ResendOrganizationInviteRequestTypedDict": ".resendorganizationinviteop",
    "ResendOrganizationInviteResendOrganizationInviteRequest": ".resendorganizationinviteop",
    "ResendOrganizationInviteResendOrganizationInviteRequestTypedDict": ".resendorganizationinviteop",
    "ResendOrganizationInviteResponseResponse": ".resendorganizationinviteop",
    "ResendOrganizationInviteResponseResponseTypedDict": ".resendorganizationinviteop",
    "ResendOrganizationInviteResponse": ".resendorganizationinviteresponse",
    "ResendOrganizationInviteResponseTypedDict": ".resendorganizationinviteresponse",
    "RevokeAPIKeyRequest": ".revokeapikeyop",
    "RevokeAPIKeyRequestTypedDict": ".revokeapikeyop",
    "RevokeAPIKeyResponseResponse": ".revokeapikeyop",
    "RevokeAPIKeyResponseResponseTypedDict": ".revokeapikeyop",
    "RevokeAPIKeyRevokeAPIKeyRequest": ".revokeapikeyop",
    "RevokeAPIKeyRevokeAPIKeyRequestTypedDict": ".revokeapikeyop",
    "RevokeAPIKeyResponse": ".revokeapikeyresponse",
    "RevokeAPIKeyResponseTypedDict": ".revokeapikeyresponse",
    "RevokeDocumentAccessRequest": ".revokedocumentaccessop",
    "RevokeDocumentAccessRequestTypedDict": ".revokedocumentaccessop",
    "RevokeDocumentAccessResponseResponse": ".revokedocumentaccessop",
    "RevokeDocumentAccessResponseResponseTypedDict": ".revokedocumentaccessop",
    "RevokeDocumentAccessResponse": ".revokedocumentaccessresponse",
    "RevokeDocumentAccessResponseTypedDict": ".revokedocumentaccessresponse",
    "RevokeOrganizationInviteRequest": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteRequestTypedDict": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteResponseResponse": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteResponseResponseTypedDict": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequest": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict": ".revokeorganizationinviteop",
    "RevokeOrganizationInviteResponse": ".revokeorganizationinviteresponse",
    "RevokeOrganizationInviteResponseTypedDict": ".revokeorganizationinviteresponse",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "SetAPIKeyQuotaRequest": ".setapikeyquotaop",
    "SetAPIKeyQuotaRequestTypedDict": ".setapikeyquotaop",
    "SetAPIKeyQuotaResponseResponse": ".setapikeyquotaop",
    "SetAPIKeyQuotaResponseResponseTypedDict": ".setapikeyquotaop",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequest": ".setapikeyquotaop",
    "SetAPIKeyQuotaSetAPIKeyQuotaRequestTypedDict": ".setapikeyquotaop",
    "SetAPIKeyQuotaResponse": ".setapikeyquotaresponse",
    "SetAPIKeyQuotaResponseTypedDict": ".setapikeyquotaresponse",
    "SetGeneralAccessRequest": ".setgeneralaccessop",
    "SetGeneralAccessRequestTypedDict": ".setgeneralaccessop",
    "SetGeneralAccessResponseResponse": ".setgeneralaccessop",
    "SetGeneralAccessResponseResponseTypedDict": ".setgeneralaccessop",
    "SetGeneralAccessSetGeneralAccessRequest": ".setgeneralaccessop",
    "SetGeneralAccessSetGeneralAccessRequestTypedDict": ".setgeneralaccessop",
    "SetGeneralAccessResponse": ".setgeneralaccessresponse",
    "SetGeneralAccessResponseTypedDict": ".setgeneralaccessresponse",
    "ShareLink": ".sharelink",
    "ShareLinkTypedDict": ".sharelink",
    "Subject": ".subject",
    "SubjectTypedDict": ".subject",
    "SubjectType": ".subjecttype",
    "TimelineEvent": ".timelineevent",
    "TimelineEventTypedDict": ".timelineevent",
    "TimelineEventType": ".timelineeventtype",
    "TransferDocumentOwnershipRequest": ".transferdocumentownershipop",
    "TransferDocumentOwnershipRequestTypedDict": ".transferdocumentownershipop",
    "TransferDocumentOwnershipResponseResponse": ".transferdocumentownershipop",
    "TransferDocumentOwnershipResponseResponseTypedDict": ".transferdocumentownershipop",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequest": ".transferdocumentownershipop",
    "TransferDocumentOwnershipTransferDocumentOwnershipRequestTypedDict": ".transferdocumentownershipop",
    "TransferDocumentOwnershipResponse": ".transferdocumentownershipresponse",
    "TransferDocumentOwnershipResponseTypedDict": ".transferdocumentownershipresponse",
    "TrashDocumentRequest": ".trashdocumentop",
    "TrashDocumentRequestTypedDict": ".trashdocumentop",
    "TrashDocumentResponseResponse": ".trashdocumentop",
    "TrashDocumentResponseResponseTypedDict": ".trashdocumentop",
    "TrashDocumentTrashDocumentRequest": ".trashdocumentop",
    "TrashDocumentTrashDocumentRequestTypedDict": ".trashdocumentop",
    "TrashDocumentResponse": ".trashdocumentresponse",
    "TrashDocumentResponseTypedDict": ".trashdocumentresponse",
    "UntrashDocumentRequest": ".untrashdocumentop",
    "UntrashDocumentRequestTypedDict": ".untrashdocumentop",
    "UntrashDocumentResponseResponse": ".untrashdocumentop",
    "UntrashDocumentResponseResponseTypedDict": ".untrashdocumentop",
    "UntrashDocumentUntrashDocumentRequest": ".untrashdocumentop",
    "UntrashDocumentUntrashDocumentRequestTypedDict": ".untrashdocumentop",
    "UntrashDocumentResponse": ".untrashdocumentresponse",
    "UntrashDocumentResponseTypedDict": ".untrashdocumentresponse",
    "UpdateDocumentAccessRequest": ".updatedocumentaccessop",
    "UpdateDocumentAccessRequestTypedDict": ".updatedocumentaccessop",
    "UpdateDocumentAccessResponseResponse": ".updatedocumentaccessop",
    "UpdateDocumentAccessResponseResponseTypedDict": ".updatedocumentaccessop",
    "UpdateDocumentAccessUpdateDocumentAccessRequest": ".updatedocumentaccessop",
    "UpdateDocumentAccessUpdateDocumentAccessRequestTypedDict": ".updatedocumentaccessop",
    "UpdateDocumentAccessResponse": ".updatedocumentaccessresponse",
    "UpdateDocumentAccessResponseTypedDict": ".updatedocumentaccessresponse",
    "UpdateDocumentRequest": ".updatedocumentop",
    "UpdateDocumentRequestTypedDict": ".updatedocumentop",
    "UpdateDocumentResponseResponse": ".updatedocumentop",
    "UpdateDocumentResponseResponseTypedDict": ".updatedocumentop",
    "UpdateDocumentUpdateDocumentRequest": ".updatedocumentop",
    "UpdateDocumentUpdateDocumentRequestTypedDict": ".updatedocumentop",
    "UpdateDocumentResponse": ".updatedocumentresponse",
    "UpdateDocumentResponseTypedDict": ".updatedocumentresponse",
    "UpdateOrganizationMemberRequest": ".updateorganizationmemberop",
    "UpdateOrganizationMemberRequestTypedDict": ".updateorganizationmemberop",
    "UpdateOrganizationMemberResponseResponse": ".updateorganizationmemberop",
    "UpdateOrganizationMemberResponseResponseTypedDict": ".updateorganizationmemberop",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequest": ".updateorganizationmemberop",
    "UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict": ".updateorganizationmemberop",
    "UpdateOrganizationMemberResponse": ".updateorganizationmemberresponse",
    "UpdateOrganizationMemberResponseTypedDict": ".updateorganizationmemberresponse",
    "UpdateOrganizationRequest": ".updateorganizationop",
    "UpdateOrganizationRequestTypedDict": ".updateorganizationop",
    "UpdateOrganizationResponseResponse": ".updateorganizationop",
    "UpdateOrganizationResponseResponseTypedDict": ".updateorganizationop",
    "UpdateOrganizationUpdateOrganizationRequest": ".updateorganizationop",
    "UpdateOrganizationUpdateOrganizationRequestTypedDict": ".updateorganizationop",
    "UpdateOrganizationResponse": ".updateorganizationresponse",
    "UpdateOrganizationResponseTypedDict": ".updateorganizationresponse",
    "UpdateVersionRequest": ".updateversionop",
    "UpdateVersionRequestTypedDict": ".updateversionop",
    "UpdateVersionResponse": ".updateversionop",
    "UpdateVersionResponseTypedDict": ".updateversionop",
    "UpdateVersionUpdateVersionRequest": ".updateversionop",
    "UpdateVersionUpdateVersionRequestTypedDict": ".updateversionop",
    "User": ".user",
    "UserTypedDict": ".user",
    "Value": ".value",
    "ValueTypedDict": ".value",
    "Version": ".version",
    "VersionTypedDict": ".version",
    "VersionRef": ".versionref",
    "VersionRefTypedDict": ".versionref",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class APIKeyQuotaTypedDict(TypedDict):
    r"""APIKeyQuota represents per-key quota status."""

    api_key_id: NotRequired[str]
    r"""The API key ID."""
    current_usage: NotRequired[int]
    r"""Current usage for this key in the billing period."""
    is_exceeded: NotRequired[bool]
    r"""Whether this key's quota is exceeded. Only true when limit is set and exceeded."""
    limit: NotRequired[Nullable[int]]
    r"""The configured limit for this key. Not set means no explicit key limit."""
    remaining: NotRequired[int]
    r"""Remaining requests for this key. Only meaningful when limit is set."""


class APIKeyQuota(BaseModel):
    r"""APIKeyQuota represents per-key quota status."""

    api_key_id: Optional[str] = None
    r"""The API key ID."""

    current_usage: Optional[int] = None
    r"""Current usage for this key in the billing period."""

    is_exceeded: Optional[bool] = None
    r"""Whether this key's quota is exceeded. Only true when limit is set and exceeded."""

    limit: OptionalNullable[int] = UNSET
    r"""The configured limit for this key. Not set means no explicit key limit."""

    remaining: Optional[int] = None
    r"""Remaining requests for this key. Only meaningful when limit is set."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["api_key_id", "current_usage", "is_exceeded", "limit", "remaining"]
        )
        nullable_fields = set(["limit"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class UpdateDocumentResponseTypedDict(TypedDict):
    r"""UpdateDocumentResponse contains the updated document."""

    document: DocumentTypedDict
    r"""Document represents a Factify document."""


class UpdateDocumentResponse(BaseModel):
    r"""UpdateDocumentResponse contains the updated document."""

    document: Document
    r"""Document represents a Factify document."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dailyusage import DailyUsage, DailyUsageTypedDict
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class GetUsageHistoryResponseTypedDict(TypedDict):
    r"""GetUsageHistoryResponse returns usage history."""

    daily_usage: NotRequired[List[DailyUsageTypedDict]]
    r"""Daily usage records."""
    organization_id: NotRequired[str]
    r"""The organization ID."""
    total_requests: NotRequired[int]
    r"""Total requests in the period."""


class GetUsageHistoryResponse(BaseModel):
    r"""GetUsageHistoryResponse returns usage history."""

    daily_usage: Optional[List[DailyUsage]] = None
    r"""Daily usage records."""

    organization_id: Optional[str] = None
    r"""The organization ID."""

    total_requests: Optional[int] = None
    r"""Total requests in the period."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["daily_usage", "organization_id", "total_requests"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel
from typing_extensions import TypedDict


class DeleteAPIKeyQuotaResponseTypedDict(TypedDict):
    r"""DeleteAPIKeyQuotaResponse confirms deletion. Empty response - success indicated by no error."""


class DeleteAPIKeyQuotaResponse(BaseModel):
    r"""DeleteAPIKeyQuotaResponse confirms deletion. Empty response - success indicated by no error."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from factify.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class UserTypedDict(TypedDict):
    r"""User represents a human user account.
    Returned by GetUser (endpoint deferred).
    """

    email: str
    id: str
    name: str
    r"""Display name of the user."""
    family_name: NotRequired[Nullable[str]]
    r"""Family name (last name) of the user."""
    given_name: NotRequired[Nullable[str]]
    r"""Given name (first name) of the user."""
    profile_image_url: NotRequired[Nullable[str]]
    r"""URL of the user's profile image."""


class User(BaseModel):
    r"""User represents a human user account.
    Returned by GetUser (endpoint deferred).
    """

    email: str

    id: str

    name: str
    r"""Display name of the user."""

    family_name: OptionalNullable[str] = UNSET
    r"""Family name (last name) of the user."""

    given_name: OptionalNullable[str] = UNSET
    r"""Given name (first name) of the user."""

    profile_image_url: OptionalNullable[str] = UNSET
    r"""URL of the user's profile image."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["family_name", "given_name", "profile_image_url"])
        nullable_fields = set(["family_name", "given_name", "profile_image_url"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .document import Document, DocumentTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class GetDocumentResponseTypedDict(TypedDict):
    r"""GetDocumentResponse contains the requested document."""

    document: DocumentTypedDict
    r"""Document represents a Factify document."""


class GetDocumentResponse(BaseModel):
    r"""GetDocumentResponse contains the requested document."""

    document: Document
    r"""Document represents a Factify document."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from factify.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DuplicateDocumentTypedDict(TypedDict):
    r"""DuplicateDocument represents a document that is a visual duplicate."""

    document_id: NotRequired[str]
    r"""Document ID of the duplicate."""
    last_viewed_at: NotRequired[datetime]
    r"""When the caller last viewed this document."""
    title: NotRequired[str]
    r"""Document title."""
    version_id: NotRequired[str]
    r"""Version ID of the duplicate."""
    version_title: NotRequired[str]
    r"""Version title."""


class DuplicateDocument(BaseModel):
    r"""DuplicateDocument represents a document that is a visual duplicate."""

    document_id: Optional[str] = None
    r"""Document ID of the duplicate."""

    last_viewed_at: Optional[datetime] = None
    r"""When the caller last viewed this document."""

    title: Optional[str] = None
    r"""Document title."""

    version_id: Optional[str] = None
    r"""Version ID of the duplicate."""

    version_title: Optional[str] = None
    r"""Version title."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["document_id", "last_viewed_at", "title", "version_id", "version_title"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .policy import Policy, PolicyTypedDict
from datetime import datetime
from factify.types import BaseModel
from typing_extensions import TypedDict


class DocumentPolicyTypedDict(TypedDict):
    r"""DocumentPolicy represents a policy attached to a document."""

    attached_at: datetime
    r"""Timestamp when policy was attached."""
    document_id: str
    r"""Document ID this policy is attached to.
    Pattern: doc_[0-9a-hjkmnp-tv-z]{26}
    """
    policy: PolicyTypedDict
    r"""Policy represents a governance policy."""


class DocumentPolicy(BaseModel):
    r"""DocumentPolicy represents a policy attached to a document."""

    attached_at: datetime
    r"""Timestamp when policy was attached."""

    document_id: str
    r"""Document ID this policy is attached to.
    Pattern: doc_[0-9a-hjkmnp-tv-z]{26}
    """

    policy: Policy
    r"""Policy represents a governance policy."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


AccessLevel = Literal[
    "private",
    "organization",
    "public",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationinvite import OrganizationInvite, OrganizationInviteTypedDict
from factify.types import BaseModel
from typing_extensions import TypedDict


class CreateOrganizationInviteResponseTypedDict(TypedDict):
    r"""CreateOrganizationInviteResponse contains the created invitation."""

    invite: OrganizationInviteTypedDict
    r"""OrganizationInvite represents an invitation to join an organization.
    accepted_fields_consistency // accepted_at and accepted_by must both be set or both be unset

    """


class CreateOrganizationInviteResponse(BaseModel):
    r"""CreateOrganizationInviteResponse contains the created invitation."""

    invite: OrganizationInvite
    r"""OrganizationInvite represents an invitation to join an organization.
    accepted_fields_consistency // accepted_at and accepted_by must both be set or both be unset

    """



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .revokedocumentaccessresponse import (
    RevokeDocumentAccessResponse,
    RevokeDocumentAccessResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class RevokeDocumentAccessRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    recipient_id: str
    r"""Recipient ID (TypeID: user_xxx or bot_xxx)."""


class RevokeDocumentAccessRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    recipient_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Recipient ID (TypeID: user_xxx or bot_xxx)."""


class RevokeDocumentAccessResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: RevokeDocumentAccessResponseTypedDict


class RevokeDocumentAccessResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: RevokeDocumentAccessResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .denyaccessrequestresponse import (
    DenyAccessRequestResponse,
    DenyAccessRequestResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class DenyAccessRequestDenyAccessRequestRequestTypedDict(TypedDict):
    r"""DenyAccessRequestRequest denies an access request."""


class DenyAccessRequestDenyAccessRequestRequest(BaseModel):
    r"""DenyAccessRequestRequest denies an access request."""


class DenyAccessRequestRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    access_request_id: str
    r"""Access request ID to deny."""
    body: DenyAccessRequestDenyAccessRequestRequestTypedDict


class DenyAccessRequestRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    access_request_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Access request ID to deny."""

    body: Annotated[
        DenyAccessRequestDenyAccessRequestRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class DenyAccessRequestResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DenyAccessRequestResponseTypedDict


class DenyAccessRequestResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DenyAccessRequestResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


RecipientType = Literal[
    "user",
    "bot",
    "organization",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from datetime import datetime
from factify import errors, models, utils
from factify._hooks import HookContext
from factify.types import OptionalNullable, UNSET
from factify.utils.unmarshal_json_response import unmarshal_json_response
from jsonpath import JSONPath
from typing import Any, Awaitable, Dict, List, Mapping, Optional, Union


class Invites(BaseSDK):
    def list(
        self,
        *,
        organization_id: str,
        status: Optional[List[models.OrganizationInviteStatus]] = None,
        page_token: Optional[str] = None,
        page_size: Optional[int] = None,
        email_contains: Optional[str] = None,
        email_exact: Optional[str] = None,
        sender_id: Optional[str] = None,
        created_after: Optional[datetime] = None,
        created_before: Optional[datetime] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.ListOrganizationInvitesResponseResponse]:
        r"""List organization invitations

        List invitations for an organization. Requires permission to invite organization members.

        :param organization_id: Organization to list invitations for.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param status: Filter by invitation status.
            If empty, returns all invitations.
            REST: ?status=pending or ?status=pending&status=expired
        :param page_token: Opaque pagination token from a previous response.
        :param page_size: Maximum number of items to return per page (1-100). Default: 50.
        :param email_contains: Case-insensitive substring match.
            REST: ?field.contains=value
        :param email_exact: Exact match (case-sensitive).
            REST: ?field.exact=value
        :param sender_id: Filter by sender. Only returns invitations sent by this user.
            REST: ?sender_id=user_01h2xcejqtf2nbrexx3vqjhp41
            Pattern: user_[0-9a-hjkmnp-tv-z]{26}
        :param created_after: Return results after this timestamp (inclusive).
        :param created_before: Return results before this timestamp (inclusive).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListOrganizationInvitesRequest(
            organization_id=organization_id,
            status=status,
            page_token=page_token,
            page_size=page_size,
            email_contains=email_contains,
            email_exact=email_exact,
            sender_id=sender_id,
            created_after=created_after,
            created_before=created_before,
        )

        req = self._build_request(
            method="GET",
            path="/v1beta/organizations/{organization_id}/invites",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listOrganizationInvites",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        def next_func() -> Optional[models.ListOrganizationInvitesResponseResponse]:
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])

            next_cursor = JSONPath("$.pagination.next_page_token").parse(body)

            if len(next_cursor) == 0:
                return None

            next_cursor = next_cursor[0]
            if next_cursor is None or str(next_cursor).strip() == "":
                return None

            return self.list(
                organization_id=organization_id,
                status=status,
                page_token=next_cursor,
                page_size=page_size,
                email_contains=email_contains,
                email_exact=email_exact,
                sender_id=sender_id,
                created_after=created_after,
                created_before=created_before,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListOrganizationInvitesResponseResponse(
                result=unmarshal_json_response(
                    models.ListOrganizationInvitesResponse, http_res
                ),
                next=next_func,
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        organization_id: str,
        status: Optional[List[models.OrganizationInviteStatus]] = None,
        page_token: Optional[str] = None,
        page_size: Optional[int] = None,
        email_contains: Optional[str] = None,
        email_exact: Optional[str] = None,
        sender_id: Optional[str] = None,
        created_after: Optional[datetime] = None,
        created_before: Optional[datetime] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> Optional[models.ListOrganizationInvitesResponseResponse]:
        r"""List organization invitations

        List invitations for an organization. Requires permission to invite organization members.

        :param organization_id: Organization to list invitations for.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param status: Filter by invitation status.
            If empty, returns all invitations.
            REST: ?status=pending or ?status=pending&status=expired
        :param page_token: Opaque pagination token from a previous response.
        :param page_size: Maximum number of items to return per page (1-100). Default: 50.
        :param email_contains: Case-insensitive substring match.
            REST: ?field.contains=value
        :param email_exact: Exact match (case-sensitive).
            REST: ?field.exact=value
        :param sender_id: Filter by sender. Only returns invitations sent by this user.
            REST: ?sender_id=user_01h2xcejqtf2nbrexx3vqjhp41
            Pattern: user_[0-9a-hjkmnp-tv-z]{26}
        :param created_after: Return results after this timestamp (inclusive).
        :param created_before: Return results before this timestamp (inclusive).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListOrganizationInvitesRequest(
            organization_id=organization_id,
            status=status,
            page_token=page_token,
            page_size=page_size,
            email_contains=email_contains,
            email_exact=email_exact,
            sender_id=sender_id,
            created_after=created_after,
            created_before=created_before,
        )

        req = self._build_request_async(
            method="GET",
            path="/v1beta/organizations/{organization_id}/invites",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listOrganizationInvites",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        def next_func() -> (
            Awaitable[Optional[models.ListOrganizationInvitesResponseResponse]]
        ):
            body = utils.unmarshal_json(http_res.text, Union[Dict[Any, Any], List[Any]])

            async def empty_result():
                return None

            next_cursor = JSONPath("$.pagination.next_page_token").parse(body)

            if len(next_cursor) == 0:
                return empty_result()

            next_cursor = next_cursor[0]
            if next_cursor is None or str(next_cursor).strip() == "":
                return empty_result()

            return self.list_async(
                organization_id=organization_id,
                status=status,
                page_token=next_cursor,
                page_size=page_size,
                email_contains=email_contains,
                email_exact=email_exact,
                sender_id=sender_id,
                created_after=created_after,
                created_before=created_before,
                retries=retries,
            )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ListOrganizationInvitesResponseResponse(
                result=unmarshal_json_response(
                    models.ListOrganizationInvitesResponse, http_res
                ),
                next=next_func,
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    def create(
        self,
        *,
        organization_id: str,
        email: str,
        idempotency_key: OptionalNullable[str] = UNSET,
        message: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateOrganizationInviteResponseResponse:
        r"""Invite a user to join an organization

        Creates an invitation and sends an email to the specified address. Returns FAILED_PRECONDITION if the email belongs to an existing organization member. Idempotency: If a PENDING invitation already exists for this email, the existing invitation is resent with a new token and refreshed expiration. Expired or revoked invitations are ignored - a new invitation is created.

        :param organization_id: Organization to invite the user to.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param email: Email address of the recipient.
        :param idempotency_key: Reserved for future use. Currently, idempotency is based on email matching:
            if a PENDING invitation exists for the same email in this organization,
            that invitation is resent rather than creating a duplicate.
        :param message: Optional custom message from the sender (max 2000 bytes to support ~500 multibyte characters).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CreateOrganizationInviteRequest(
            organization_id=organization_id,
            body=models.CreateOrganizationInviteCreateOrganizationInviteRequest(
                email=email,
                idempotency_key=idempotency_key,
                message=message,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.CreateOrganizationInviteCreateOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.CreateOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.CreateOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        organization_id: str,
        email: str,
        idempotency_key: OptionalNullable[str] = UNSET,
        message: OptionalNullable[str] = UNSET,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateOrganizationInviteResponseResponse:
        r"""Invite a user to join an organization

        Creates an invitation and sends an email to the specified address. Returns FAILED_PRECONDITION if the email belongs to an existing organization member. Idempotency: If a PENDING invitation already exists for this email, the existing invitation is resent with a new token and refreshed expiration. Expired or revoked invitations are ignored - a new invitation is created.

        :param organization_id: Organization to invite the user to.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param email: Email address of the recipient.
        :param idempotency_key: Reserved for future use. Currently, idempotency is based on email matching:
            if a PENDING invitation exists for the same email in this organization,
            that invitation is resent rather than creating a duplicate.
        :param message: Optional custom message from the sender (max 2000 bytes to support ~500 multibyte characters).
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CreateOrganizationInviteRequest(
            organization_id=organization_id,
            body=models.CreateOrganizationInviteCreateOrganizationInviteRequest(
                email=email,
                idempotency_key=idempotency_key,
                message=message,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.CreateOrganizationInviteCreateOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.CreateOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.CreateOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    def accept(
        self,
        *,
        organization_id: str,
        token: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AcceptOrganizationInviteResponseResponse:
        r"""Accept an invitation

        Accepts the invitation and adds the authenticated user as a member of the organization. The authenticated user's verified email must match the invitation email (case-insensitive). Returns PERMISSION_DENIED if emails don't match, FAILED_PRECONDITION if the user is already a member, or NOT_FOUND if the invitation is invalid/expired.

        :param organization_id: Organization the invitation belongs to (for validation).
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param token: The invitation token from the email link.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.AcceptOrganizationInviteRequest(
            organization_id=organization_id,
            body=models.AcceptOrganizationInviteAcceptOrganizationInviteRequest(
                token=token,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites/accept",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.AcceptOrganizationInviteAcceptOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="acceptOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.AcceptOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.AcceptOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    async def accept_async(
        self,
        *,
        organization_id: str,
        token: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.AcceptOrganizationInviteResponseResponse:
        r"""Accept an invitation

        Accepts the invitation and adds the authenticated user as a member of the organization. The authenticated user's verified email must match the invitation email (case-insensitive). Returns PERMISSION_DENIED if emails don't match, FAILED_PRECONDITION if the user is already a member, or NOT_FOUND if the invitation is invalid/expired.

        :param organization_id: Organization the invitation belongs to (for validation).
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param token: The invitation token from the email link.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.AcceptOrganizationInviteRequest(
            organization_id=organization_id,
            body=models.AcceptOrganizationInviteAcceptOrganizationInviteRequest(
                token=token,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites/accept",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.AcceptOrganizationInviteAcceptOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="acceptOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.AcceptOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.AcceptOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    def resend(
        self,
        *,
        organization_id: str,
        invite_id: str,
        body: Union[
            models.ResendOrganizationInviteResendOrganizationInviteRequest,
            models.ResendOrganizationInviteResendOrganizationInviteRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ResendOrganizationInviteResponseResponse:
        r"""Resend an invitation email

        Resend an invitation email to the recipient. Useful if the original email was lost or expired. Requires permission to invite organization members.

        :param organization_id: Organization the invitation belongs to.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param invite_id: Invitation ID to resend.
            Pattern: inv_[0-9a-hjkmnp-tv-z]{26}
        :param body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ResendOrganizationInviteRequest(
            organization_id=organization_id,
            invite_id=invite_id,
            body=utils.get_pydantic_model(
                body, models.ResendOrganizationInviteResendOrganizationInviteRequest
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites/{invite_id}/resend",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.ResendOrganizationInviteResendOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="resendOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ResendOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.ResendOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    async def resend_async(
        self,
        *,
        organization_id: str,
        invite_id: str,
        body: Union[
            models.ResendOrganizationInviteResendOrganizationInviteRequest,
            models.ResendOrganizationInviteResendOrganizationInviteRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ResendOrganizationInviteResponseResponse:
        r"""Resend an invitation email

        Resend an invitation email to the recipient. Useful if the original email was lost or expired. Requires permission to invite organization members.

        :param organization_id: Organization the invitation belongs to.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param invite_id: Invitation ID to resend.
            Pattern: inv_[0-9a-hjkmnp-tv-z]{26}
        :param body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ResendOrganizationInviteRequest(
            organization_id=organization_id,
            invite_id=invite_id,
            body=utils.get_pydantic_model(
                body, models.ResendOrganizationInviteResendOrganizationInviteRequest
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites/{invite_id}/resend",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.ResendOrganizationInviteResendOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="resendOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.ResendOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.ResendOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    def revoke(
        self,
        *,
        organization_id: str,
        invite_id: str,
        body: Union[
            models.RevokeOrganizationInviteRevokeOrganizationInviteRequest,
            models.RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.RevokeOrganizationInviteResponseResponse:
        r"""Revoke an invitation

        Revoke a pending invitation, preventing the recipient from joining. Requires permission to manage organization members.

        :param organization_id: Organization the invitation belongs to.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param invite_id: Invitation ID to revoke.
            Pattern: inv_[0-9a-hjkmnp-tv-z]{26}
        :param body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.RevokeOrganizationInviteRequest(
            organization_id=organization_id,
            invite_id=invite_id,
            body=utils.get_pydantic_model(
                body, models.RevokeOrganizationInviteRevokeOrganizationInviteRequest
            ),
        )

        req = self._build_request(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites/{invite_id}/revoke",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.RevokeOrganizationInviteRevokeOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="revokeOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.RevokeOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.RevokeOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)

    async def revoke_async(
        self,
        *,
        organization_id: str,
        invite_id: str,
        body: Union[
            models.RevokeOrganizationInviteRevokeOrganizationInviteRequest,
            models.RevokeOrganizationInviteRevokeOrganizationInviteRequestTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.RevokeOrganizationInviteResponseResponse:
        r"""Revoke an invitation

        Revoke a pending invitation, preventing the recipient from joining. Requires permission to manage organization members.

        :param organization_id: Organization the invitation belongs to.
            Pattern: org_[0-9a-hjkmnp-tv-z]{26}
        :param invite_id: Invitation ID to revoke.
            Pattern: inv_[0-9a-hjkmnp-tv-z]{26}
        :param body:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.RevokeOrganizationInviteRequest(
            organization_id=organization_id,
            invite_id=invite_id,
            body=utils.get_pydantic_model(
                body, models.RevokeOrganizationInviteRevokeOrganizationInviteRequest
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/v1beta/organizations/{organization_id}/invites/{invite_id}/revoke",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.body,
                False,
                False,
                "json",
                models.RevokeOrganizationInviteRevokeOrganizationInviteRequest,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="revokeOrganizationInvite",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "401", "403", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return models.RevokeOrganizationInviteResponseResponse(
                result=unmarshal_json_response(
                    models.RevokeOrganizationInviteResponse, http_res
                ),
                headers={},
            )
        if utils.match_response(
            http_res, ["400", "401", "403", "404"], "application/json"
        ):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(errors.ErrorResponseData, http_res)
            raise errors.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FactifyDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FactifyDefaultError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createsharelinkresponse import (
    CreateShareLinkResponse,
    CreateShareLinkResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateShareLinkCreateShareLinkRequestTypedDict(TypedDict):
    r"""CreateShareLinkRequest creates a share link for a document."""


class CreateShareLinkCreateShareLinkRequest(BaseModel):
    r"""CreateShareLinkRequest creates a share link for a document."""


class CreateShareLinkRequestTypedDict(TypedDict):
    document_id: str
    r"""Document ID."""
    body: CreateShareLinkCreateShareLinkRequestTypedDict


class CreateShareLinkRequest(BaseModel):
    document_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Document ID."""

    body: Annotated[
        CreateShareLinkCreateShareLinkRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateShareLinkResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: CreateShareLinkResponseTypedDict


class CreateShareLinkResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: CreateShareLinkResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


DocumentRole = Literal[
    "viewer",
    "commenter",
    "collaborator",
    "admin",
    "owner",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationrole import OrganizationRole
from .updateorganizationmemberresponse import (
    UpdateOrganizationMemberResponse,
    UpdateOrganizationMemberResponseTypedDict,
)
from factify.types import BaseModel
from factify.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict(TypedDict):
    r"""UpdateOrganizationMemberRequest identifies a member and the new role."""

    role: OrganizationRole


class UpdateOrganizationMemberUpdateOrganizationMemberRequest(BaseModel):
    r"""UpdateOrganizationMemberRequest identifies a member and the new role."""

    role: OrganizationRole


class UpdateOrganizationMemberRequestTypedDict(TypedDict):
    organization_id: str
    r"""Organization the member belongs to.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """
    user_id: str
    r"""User account ID of the member to update.
    Pattern: user_[0-9a-hjkmnp-tv-z]{26}
    """
    body: UpdateOrganizationMemberUpdateOrganizationMemberRequestTypedDict


class UpdateOrganizationMemberRequest(BaseModel):
    organization_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Organization the member belongs to.
    Pattern: org_[0-9a-hjkmnp-tv-z]{26}
    """

    user_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""User account ID of the member to update.
    Pattern: user_[0-9a-hjkmnp-tv-z]{26}
    """

    body: Annotated[
        UpdateOrganizationMemberUpdateOrganizationMemberRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateOrganizationMemberResponseResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: UpdateOrganizationMemberResponseTypedDict


class UpdateOrganizationMemberResponseResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: UpdateOrganizationMemberResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subjecttype import SubjectType
from factify.types import BaseModel
from typing_extensions import TypedDict


class SubjectTypedDict(TypedDict):
    r"""Subject is a lightweight reference to either a user or a bot.
    Used in embedded fields like created_by.
    For full details, call GetUser or GetBot with the subject's id.
    subject_type_matches_id_prefix // id prefix must match type (user_ for user, bot_ for bot)

    """

    id: str
    r"""Unique ID. user_xxx for users, bot_xxx for bots."""
    name: str
    r"""Display name of the user or bot."""
    type: SubjectType


class Subject(BaseModel):
    r"""Subject is a lightweight reference to either a user or a bot.
    Used in embedded fields like created_by.
    For full details, call GetUser or GetBot with the subject's id.
    subject_type_matches_id_prefix // id prefix must match type (user_ for user, bot_ for bot)

    """

    id: str
    r"""Unique ID. user_xxx for users, bot_xxx for bots."""

    name: str
    r"""Display name of the user or bot."""

    type: SubjectType
